@@ -21,8 +21,8 @@ import (
 	"github.com/spf13/cobra"
 	"gotest.tools/v3/assert"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	eventingv1beta1 "knative.dev/eventing/pkg/apis/eventing/v1beta1"
-	messagingv1beta1 "knative.dev/eventing/pkg/apis/messaging/v1beta1"
+	eventingv1 "knative.dev/eventing/pkg/apis/eventing/v1"
+	messagingv1 "knative.dev/eventing/pkg/apis/messaging/v1"
 	"knative.dev/pkg/apis"
 	duckv1 "knative.dev/pkg/apis/duck/v1"
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
@@ -78,12 +78,12 @@ func TestResolve(t *testing.T) {
 		TypeMeta:   metav1.TypeMeta{Kind: "Service", APIVersion: "serving.knative.dev/v1"},
 		ObjectMeta: metav1.ObjectMeta{Name: "mysvc", Namespace: "default"},
 	}
-	defaultBroker := &eventingv1beta1.Broker{
-		TypeMeta:   metav1.TypeMeta{Kind: "Broker", APIVersion: "eventing.knative.dev/v1beta1"},
+	defaultBroker := &eventingv1.Broker{
+		TypeMeta:   metav1.TypeMeta{Kind: "Broker", APIVersion: "eventing.knative.dev/v1"},
 		ObjectMeta: metav1.ObjectMeta{Name: "default", Namespace: "default"},
 	}
-	pipeChannel := &messagingv1beta1.Channel{
-		TypeMeta:   metav1.TypeMeta{Kind: "Channel", APIVersion: "messaging.knative.dev/v1beta1"},
+	pipeChannel := &messagingv1.Channel{
+		TypeMeta:   metav1.TypeMeta{Kind: "Channel", APIVersion: "messaging.knative.dev/v1"},
 		ObjectMeta: metav1.ObjectMeta{Name: "pipe", Namespace: "default"},
 	}
 
@@ -101,13 +101,13 @@ func TestResolve(t *testing.T) {
 		{"ksvc:absent", nil, "\"absent\" not found"},
 		{"broker:default", &duckv1.Destination{
 			Ref: &duckv1.KReference{Kind: "Broker",
-				APIVersion: "eventing.knative.dev/v1beta1",
+				APIVersion: "eventing.knative.dev/v1",
 				Namespace:  "default",
 				Name:       "default"}}, ""},
 		{"channel:pipe",
 			&duckv1.Destination{
 				Ref: &duckv1.KReference{Kind: "Channel",
-					APIVersion: "messaging.knative.dev/v1beta1",
+					APIVersion: "messaging.knative.dev/v1",
 					Namespace:  "default",
 					Name:       "pipe",
 				},
@@ -139,12 +139,12 @@ func TestResolveWithNamespace(t *testing.T) {
 		TypeMeta:   metav1.TypeMeta{Kind: "Service", APIVersion: "serving.knative.dev/v1"},
 		ObjectMeta: metav1.ObjectMeta{Name: "mysvc", Namespace: "my-namespace"},
 	}
-	defaultBroker := &eventingv1beta1.Broker{
-		TypeMeta:   metav1.TypeMeta{Kind: "Broker", APIVersion: "eventing.knative.dev/v1beta1"},
+	defaultBroker := &eventingv1.Broker{
+		TypeMeta:   metav1.TypeMeta{Kind: "Broker", APIVersion: "eventing.knative.dev/v1"},
 		ObjectMeta: metav1.ObjectMeta{Name: "default", Namespace: "my-namespace"},
 	}
-	pipeChannel := &messagingv1beta1.Channel{
-		TypeMeta:   metav1.TypeMeta{Kind: "Channel", APIVersion: "messaging.knative.dev/v1beta1"},
+	pipeChannel := &messagingv1.Channel{
+		TypeMeta:   metav1.TypeMeta{Kind: "Channel", APIVersion: "messaging.knative.dev/v1"},
 		ObjectMeta: metav1.ObjectMeta{Name: "pipe", Namespace: "my-namespace"},
 	}
 
@@ -156,12 +156,12 @@ func TestResolveWithNamespace(t *testing.T) {
 				Name:       "mysvc"}}, ""},
 		{"broker:default:my-namespace", &duckv1.Destination{
 			Ref: &duckv1.KReference{Kind: "Broker",
-				APIVersion: "eventing.knative.dev/v1beta1",
+				APIVersion: "eventing.knative.dev/v1",
 				Namespace:  "my-namespace",
 				Name:       "default"}}, ""},
 		{"channel:pipe:my-namespace", &duckv1.Destination{
 			Ref: &duckv1.KReference{Kind: "Channel",
-				APIVersion: "messaging.knative.dev/v1beta1",
+				APIVersion: "messaging.knative.dev/v1",
 				Namespace:  "my-namespace",
 				Name:       "pipe"}}, ""},
 	}
@@ -178,3 +178,29 @@ func TestResolveWithNamespace(t *testing.T) {
 		}
 	}
 }
+
+func TestSinkToString(t *testing.T) {
+	sink := duckv1.Destination{
+		Ref: &duckv1.KReference{Kind: "Service",
+			APIVersion: "serving.knative.dev/v1",
+			Namespace:  "my-namespace",
+			Name:       "mysvc"}}
+	expected := "ksvc:mysvc"
+	assert.Equal(t, expected, SinkToString(sink))
+	sink = duckv1.Destination{
+		Ref: &duckv1.KReference{Kind: "Broker",
+			APIVersion: "eventing.knative.dev/v1",
+			Namespace:  "my-namespace",
+			Name:       "default"}}
+	expected = "broker:default"
+	assert.Equal(t, expected, SinkToString(sink))
+
+	uri := "http://target.example.com"
+	targetExampleCom, err := apis.ParseURL(uri)
+	assert.NilError(t, err)
+	sink = duckv1.Destination{
+		URI: targetExampleCom,
+	}
+	assert.Equal(t, uri, SinkToString(sink))
+	assert.Equal(t, "", SinkToString(duckv1.Destination{}))
+}
