@@ -37,10 +37,19 @@ var sourceTypeDescription = map[string]string{
 	"KafkaSource": "Route events from Apache Kafka Server to addressable",
 }
 
+var sourceTypeSupported = map[string]string{
+	"ApiServerSource": "X",
+	"SinkBinding":     "X",
+	"PingSource":      "X",
+	"ContainerSource": "X",
+	"KafkaSource":     "",
+}
+
 // ListTypesHandlers handles printing human readable table for `kn source list-types`
 func ListTypesHandlers(h printers.PrintHandler) {
 	sourceTypesColumnDefinitions := []metav1beta1.TableColumnDefinition{
 		{Name: "Type", Type: "string", Description: "Kind / Type of the source type", Priority: 1},
+		{Name: "S", Type: "string", Description: "Supported source", Priority: 1},
 		{Name: "Name", Type: "string", Description: "Name of the source type", Priority: 1},
 		{Name: "Description", Type: "string", Description: "Description of the source type", Priority: 1},
 	}
@@ -78,7 +87,7 @@ func printSourceTypes(sourceType unstructured.Unstructured, options printers.Pri
 	row := metav1beta1.TableRow{
 		Object: runtime.RawExtension{Object: &sourceType},
 	}
-	row.Cells = append(row.Cells, kind, name, sourceTypeDescription[kind])
+	row.Cells = append(row.Cells, kind, sourceTypeSupported[kind], name, sourceTypeDescription[kind])
 	return []metav1beta1.TableRow{row}, nil
 }
 
